@@ -21,7 +21,7 @@ class ENSEMBLE(MCDA):
     def ranking_by_voting(self, list_mcda_intances, voting='soft'):  
         """
         The idea behind the ranking_by_voting Method is to combine conceptually different MCDA Raking Methods and 
-        use a majority vote (hard vote) or the average of preferences (soft vote) to estabilish a ranking. 
+        use a majority vote (hard vote) or the average of preferences normalized (soft vote) to estabilish a ranking. 
         
         It can be useful for a set of equally well performing model in order to balance out their individual weaknesses.
 
@@ -77,6 +77,11 @@ class ENSEMBLE(MCDA):
         df_ranking["rank"] = i
         self.df_decision = df_ranking.sort_index()
 
+
+    def __norm(self, df):
+        normalized = df.iloc[:, 1:]/df.iloc[:, 1:].sum(axis=0)
+        self.df_normalized = normalized
+
     def __soft_voting(self, list_mcda_intances):
         df_soft = pd.DataFrame(np.zeros((list_mcda_intances[0].df_decision.shape[0], len(list_mcda_intances))))
         column = 0
@@ -88,8 +93,12 @@ class ENSEMBLE(MCDA):
             df_soft = df_soft.rename(columns={column: type(m).__name__})
             column = column + 1
 
-        df_soft["voting"] = df_soft.iloc[:,:].mean(axis=1)
-        
+        # normalizing
+        self.__norm(df_soft)
+        df_soft = self.df_normalized
+        df_soft["voting"] = self.df_normalized.iloc[:,:].mean(axis=1)
+        # df_soft["voting"] = df_soft.iloc[:,:].mean(axis=1)
+
         df_soft = pd.DataFrame(list_mcda_intances[0].df_decision.iloc[:, 0]).join(df_soft)
         
         self.df_decision = df_soft
